'use strict';


const commonConfig = require('./webpack.config');
const path = require('path');
const description = require(path.join(process.cwd(), 'description'));
const CleanWebpackPlugin = require('clean-webpack-plugin');
console.log(description.libName);

module.exports = Object.assign(commonConfig, {
    entry: [path.join(process.cwd(), description.mainEntryPath)],
    output: {
        filename: description.moduleName + '.js',
        library: description.libName,
        libraryTarget: 'umd',
        path: path.join(process.cwd(), 'dist')
    },
    externals: [
        // super custom needs/ should overrides deps below
        ...description.webpackBuild.externals,

        // third-party dependencies
        /angular/,
        /fast-json-patch/,
        'ng-file-upload',
        'ngstorage',
        'ng-idle',
        'fast-json-patch',
        /sizzle/,
        'metismenu',
        /animate/,
        'toastr',
        'jquery-ui',
        'jsoneditor',
        'jquery-slimscroll',
        /flot/,
        /ladda/,
        /ng-device-detector/,
        /spinkit/,
        /icheck/,
        /re-tree/,
        /ui-select/,
        /ua-device-detector/,
        { jquery: '$' },
        { lodash: '_' },
        /bootstrap/,
        /font-awesome/,

        // own module external dependencies
        {
            'oasi-widgets': {
                commonjs: "oasi-widgets",
                commonjs2: "oasi-widgets",
                amd: "oasi-widgets",
                root: 'oasiWidgets'
            }
        },
        {
            'oasi-cryptopro': {
                commonjs: "oasi-cryptopro",
                commonjs2: "oasi-cryptopro",
                amd: "oasi-cryptopro",
                root: 'oasiCryptopro'
            }
        },
        {
            'oasi-security': {
                commonjs: "oasi-security",
                commonjs2: "oasi-security",
                amd: "oasi-security",
                root: 'oasiSecurity'
            }
        },
        {
            'oasi-bpm-history': {
                commonjs: "oasi-bpm-history",
                commonjs2: "oasi-bpm-history",
                amd: 'oasi-bpm-history',
                root: 'oasiBpmHistory'
            }
        },
        {
            'orders-document': {
                commonjs: 'orders-document',
                commonjs2: 'orders-document',
                amd: 'orders-document',
                root: 'ordersDocument'
            }
        },
        {
            'gpzu-schema': {
                commonjs: 'gpzu-schema',
                commonjs2: 'gpzu-schema',
                amd: 'gpzu-schema',
                root: 'gpzuSchema'
            }
        },
        {
            'cadesplugin-api': {
                commonjs: 'cadesplugin-api',
                commonjs2: 'cadesplugin-api',
                amd: 'cadesplugin-api',
                root: 'cadesplugin'
            }
        },
        {
            'sprit-document': {
                commonjs: 'sprit-document',
                commonjs2: 'sprit-document',
                amd: 'sprit-document',
                root: 'spritDocument'
            }
        },
        {
            'orders-tasks': {
                commonjs: 'orders-tasks',
                commonjs2: 'orders-tasks',
                amd: 'orders-tasks',
                root: 'ordersTasks'
            }
        },
        {
            'oasi-task-wrapper': {
                commonjs: 'oasi-task-wrapper',
                commonjs2: 'oasi-task-wrapper',
                amd: 'oasi-task-wrapper',
                root: 'oasiTaskWrapper'
            }
        },
        {
            'oasi-showcase': {
                commonjs: 'oasi-showcase',
                commonjs2: 'oasi-showcase',
                amd: 'oasi-showcase',
                root: 'oasiShowcase'
            }
        },
        {
            'oasi-my-tasks': {
                commonjs: 'oasi-my-tasks',
                commonjs2: 'oasi-my-tasks',
                amd: 'oasi-my-tasks',
                root: 'oasiMyTasks'
            }
        },
        {
            'oasi-main-theme': {
                commonjs: 'oasi-main-theme',
                commonjs2: 'oasi-main-theme',
                amd: 'oasi-main-theme',
                root: 'oasiMainTheme'
            }
        },
        {
            'oasi-logs': {
                commonjs: 'oasi-logs',
                commonjs2: 'oasi-logs',
                amd: 'oasi-logs',
                root: 'oasiLogs'
            }
        },
        {
            'oasi-file-manager': {
                commonjs: 'oasi-file-manager',
                commonjs2: 'oasi-file-manager',
                amd: 'oasi-file-manager',
                root: 'oasiFileManager'
            }
        },
        {
            'oasi-config-box': {
                commonjs: 'oasi-config-box',
                commonjs2: 'oasi-config-box',
                amd: 'oasi-config-box',
                root: 'oasiConfigBox'
            }
        },
        {
            'isogd-widget': {
                commonjs: 'isogd-widget',
                commonjs2: 'isogd-widget',
                amd: 'isogd-widget',
                root: 'isogdWidget'
            }
        },
        {
            'isogd-tasks': {
                commonjs: 'isogd-tasks',
                commonjs2: 'isogd-tasks',
                amd: 'isogd-tasks',
                root: 'isogdTasks'
            }
        },
        {
            'isogd-showcase': {
                commonjs: 'isogd-showcase',
                commonjs2: 'isogd-showcase',
                amd: 'isogd-showcase',
                root: 'isogdShowcase'
            }
        },
        {
            'isogd-my-tasks': {
                commonjs: 'isogd-my-tasks',
                commonjs2: 'isogd-my-tasks',
                amd: 'isogd-my-tasks',
                root: 'isogdMyTasks'
            }
        },
        {
            'isogd-document': {
                commonjs: 'isogd-document',
                commonjs2: 'isogd-document',
                amd: 'isogd-document',
                root: 'isogdDocument'
            }
        },
        {
            'gpzu-card': {
                commonjs: 'gpzu-card',
                commonjs2: 'gpzu-card',
                amd: 'gpzu-card',
                root: 'gpzuCard'
            }
        },
        {
            'oasi-footer': {
                commonjs: 'oasi-footer',
                commonjs2: 'oasi-footer',
                amd: 'oasi-footer',
                root: 'oasiFooter'
            }
        },
        {
            'oasi-breadcrumbs': {
                commonjs: 'oasi-breadcrumbs',
                commonjs2: 'oasi-breadcrumbs',
                amd: 'oasi-breadcrumbs',
                root: 'oasiBreadcrumbs'
            }
        },
        {
            'oasi-sidebar': {
                commonjs: 'oasi-sidebar',
                commonjs2: 'oasi-sidebar',
                amd: 'oasi-sidebar',
                root: 'oasiSidebar'
            }
        },
        {
            'oasi-navbar': {
                commonjs: 'oasi-navbar',
                commonjs2: 'oasi-navbar',
                amd: 'oasi-navbar',
                root: 'oasiNavbar'
            }
        },
        {
            'admord-rest': {
                commonjs: 'admord-rest',
                commonjs2: 'admord-rest',
                amd: 'admord-rest',
                root: 'admordRest'
            }
        },
        {
            'gpzu-rest': {
                commonjs: 'gpzu-rest',
                commonjs2: 'gpzu-rest',
                amd: 'gpzu-rest',
                root: 'gpzuRest'
            }
        },
        {
            'isogd-document-rest': {
                commonjs: 'isogd-document-rest',
                commonjs2: 'isogd-document-rest',
                amd: 'isogd-document-rest',
                root: 'isogdDocumentRest'
            }
        },
        {
            'isogd-dossier-rest': {
                commonjs: 'isogd-dossier-rest',
                commonjs2: 'isogd-dossier-rest',
                amd: 'isogd-dossier-rest',
                root: 'isogdDossierRest'
            }
        },
        {
            'isogd-file-rest': {
                commonjs: 'isogd-file-rest',
                commonjs2: 'isogd-file-rest',
                amd: 'isogd-file-rest',
                root: 'isogdFileRest'
            }
        },
        {
            'isogd-solar-rest': {
                commonjs: 'isogd-solar-rest',
                commonjs2: 'isogd-solar-rest',
                amd: 'isogd-solar-rest',
                root: 'isogdSolarRest'
            }
        },
        {
            'oasi-bpm-rest': {
                commonjs: 'oasi-bpm-rest',
                commonjs2: 'oasi-bpm-rest',
                amd: 'oasi-bpm-rest',
                root: 'oasiBpmRest'
            }
        },
        {
            'oasi-file-rest': {
                commonjs: 'oasi-file-rest',
                commonjs2: 'oasi-file-rest',
                amd: 'oasi-file-rest',
                root: 'oasiFileRest'
            }
        },
        {
            'oasi-nsi-rest': {
                commonjs: 'oasi-nsi-rest',
                commonjs2: 'oasi-nsi-rest',
                amd: 'oasi-nsi-rest',
                root: 'oasiNsiRest'
            }
        },
        {
            'oasi-wordreporter-rest': {
                commonjs: 'oasi-wordreporter-rest',
                commonjs2: 'oasi-wordreporter-rest',
                amd: 'oasi-wordreporter-rest',
                root: 'oasiWordreporter-Rest'
            }
        },
        {
            'orders-rest': {
                commonjs: 'orders-rest',
                commonjs2: 'orders-rest',
                amd: 'orders-rest',
                root: 'ordersRest'
            }
        },
        {
            'pzz-rest': {
                commonjs: 'pzz-rest',
                commonjs2: 'pzz-rest',
                amd: 'pzz-rest',
                root: 'pzzRest'
            }
        },
        {
            'ssmka-rest': {
                commonjs: 'ssmka-rest',
                commonjs2: 'ssmka-rest',
                amd: 'ssmka-rest',
                root: 'ssmkaRest'
            }
        },
        {
            'isogd-document-link-rest': {
                commonjs: 'isogd-document-link-rest',
                commonjs2: 'isogd-document-link-rest',
                amd: 'isogd-document-link-rest',
                root: 'isogdDocumentLinkRest'
            }
        },
        {
            'oasi-solar-rest': {
                commonjs: 'oasi-solar-rest',
                commonjs2: 'oasi-solar-rest',
                amd: 'oasi-solar-rest',
                root: 'oasiSolarRest'
            }
        },
        {
            'isogd-gis-rest': {
                commonjs: 'isogd-gis-rest',
                commonjs2: 'isogd-gis-rest',
                amd: 'isogd-gis-rest',
                root: 'isogdGisRest'
            }
        },
        {
            'sprit-rest': {
                commonjs: 'sprit-rest',
                commonjs2: 'sprit-rest',
                amd: 'sprit-rest',
                root: 'spritRest'
            }
        },
        {
            'oasi-auth-rest': {
                commonjs: 'oasi-auth-rest',
                commonjs2: 'oasi-auth-rest',
                amd: 'oasi-auth-rest',
                root: 'oasiAuthRest'
            }
        },
        // module styles
        /^metisMenu(.*)css$/,
        /^oasi-widgets(.*)css$/,
        /^isogd-widget(.*)css$/,
        /^orders-document(.*)css$/,
        /^oasi-task-wrapper(.*)css$/,
        /^oasi-bpm-history(.*)css$/,
        /^isogd-document(.*)css$/,
        /^oasi-task-wrapper(.*)css$/,
        /^sprit-document(.*)css$/,
        /^orders-tasks(.*)css$/,
        /^oasi-task-wrapper(.*)css$/,
        /^oasi-showcase(.*)css$/,
        /^oasi-my-tasks(.*)css$/,
        /^oasi-main-theme(.*)css$/,
        /^oasi-file-manager(.*)css$/,
        /^oasi-config-box(.*)css$/,
        /^isogd-widget(.*)css$/,
        /^isogd-tasks(.*)css$/,
        /^isogd-showcase(.*)css$/,
        /^isogd-my-tasks(.*)css$/,
        /^isogd-document(.*)css$/,
        /^gpzu-card(.*)css$/,
        /^oasi-footer(.*)css$/,
        /^oasi-breadcrumbs(.*)css$/,
        /^oasi-sidebar(.*)css$/,
        /^oasi-navbar(.*)css$/
    ],
    plugins: [
        new CleanWebpackPlugin([path.join(process.cwd(), 'dist'), path.join(process.cwd(), '@types')], { root: process.cwd() }),
        ...commonConfig.plugins
    ]
});