'use strict';

const webpack = require('webpack');
const FailPlugin = require('webpack-fail-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const path = require('path');
const description = require(path.join(process.cwd(), 'description'));

module.exports = {
    module: {
        loaders: [{
                test: /\.json$/,
                loaders: [
                    require.resolve('json-loader')
                ]
            },
            {
                test: /\.(woff|woff2|ttf|eot|svg)$/,
                loader: require.resolve('url-loader') + '?limit=1024&name=fonts/[name].[ext]'
            },
            {
                test: /\.(png|jpg|jpeg|gif|ico)$/,
                loader: require.resolve('file-loader') + '?name=images/[name].[ext]'
            },
            {
                test: /\.(css|scss)$/,
                loaders: ExtractTextPlugin.extract({
                    fallback: require.resolve('style-loader'),
                    use: require.resolve('css-loader') + '?sourceMap!' + require.resolve('resolve-url-loader') + '!' + require.resolve('sass-loader') + '?sourceMap'
                })
            },
            {
                test: /\.ts$/,
                exclude: /node_modules/,
                loaders: [
                    require.resolve('ng-annotate-loader'),
                    {
                        loader: require.resolve('ts-loader'),
                        options: {
                            configFile: path.resolve(process.cwd(), "tsconfig.json")
                        }
                    }
                ]
            },
            {
                test: /\.html$/,
                loaders: [
                    require.resolve('html-loader') + '?minimize=false'
                ],

            }
        ],
    },
    devtool: 'source-map',
    plugins: [
        new webpack.IgnorePlugin(/regenerator|nodent|js\-beautify/, /ajv/),
        new webpack.optimize.OccurrenceOrderPlugin(),
        new webpack.NoEmitOnErrorsPlugin(),
        new ExtractTextPlugin(description.moduleName + '.css'),
        FailPlugin,
        new webpack.ProvidePlugin({
            $: "jquery",
            jQuery: "jquery",
            'window.jQuery': 'jquery'
        })
    ],
    resolve: {
        alias: {
            jquery: "jquery/src/jquery",
            $$: "jquery/src/jquery",
            _: "lodash/lodash",
            gpzuSchema: "gpzu-schema"
        },
        extensions: [
            '.webpack.js',
            '.web.js',
            '.js',
            '.ts'
        ]
    }
};