'use strict';

// Do this as the first thing so that any code reading it knows the right env.
process.env.BABEL_ENV = 'development';
process.env.NODE_ENV = 'development';

// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the future, promise rejections that are not handled will
// terminate the Node.js process with a non-zero exit code.
process.on('unhandledRejection', err => {
    throw err;
});

const chalk = require('chalk');
const WebpackDevServer = require('webpack-dev-server');
const openBrowser = require('./utils/openBrowser');
const webpack = require('webpack');
const config = require('../config/webpack.config.dev');
const path = require('path');
const description = require(path.join(process.cwd(), 'description'));

start();

function start() {
    let publicPath = description.webpackDev.devServer.publicPath ? description.webpackDev.devServer.publicPath : '/';

    config.entry.app.unshift("webpack-dev-server/client?http://localhost:8000/");
    let compiler = webpack(config);
    const devServer = new WebpackDevServer(compiler, {
        proxy:  Object.assign({
            "/isogd-rest": "http://oasi-dev.reinform-int.ru",
            "/isogd-oldsystem-rest": "http://oasi-dev.reinform-int.ru:8063",
            "/oasi/search": "http://oasi-dev.reinform-int.ru",
            "/activiti-rest": "http://oasi-dev.reinform-int.ru",
            "/nsi-api": "http://oasi-dev.reinform-int.ru",
            "/auth": "http://oasi-dev.reinform-int.ru/oasi",
            "/oasi/oasi-rest/api": "http://oasi-dev.reinform-int.ru",
            "/nsi-api/v1": "http://oasi-dev.reinform-int.ru",
            "/isogd-solr-rest": "http://oasi-dev.reinform-int.ru:8093",
            "/oasi-solr-rest": "http://oasi-dev.reinform-int.ru",
            "/gpzu-rest": "http://oasi-dev.reinform-int.ru:8073",
            "/pzz-server-rest": " http://oasi-dev.reinform-int.ru:8073",
            "/adm-order": "http://oasi-dev.reinform-int.ru",
            "/ssmka": "http://oasi-dev.reinform-int.ru",
            "/egip-rest": "http://oasi-dev.reinform-int.ru:8094",
            "/instruction-rest": "http://oasi-dev.reinform-int.ru/oasi"

        }, description.webpackDev.devServer.proxy),
        stats: {
            colors: true
        },
        inline: true,
        publicPath
    });
    // Launch WebpackDevServer.
    devServer.listen(description.webpackDev.devServer.port, 'localhost', err => {
        if (err) {
            return console.log(err);
        }
        console.log(chalk.cyan('Starting the development server...\n'));
        openBrowser(openBrowser('http://localhost:' + description.webpackDev.devServer.port + publicPath));
    });
}